<?php

namespace Drupal\field_fallback\Plugin;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Plugin\PluginFormInterface;

/**
 * Interface for field fallback converter plugins.
 */
interface FieldFallbackConverterInterface extends PluginInspectionInterface, ConfigurableInterface, PluginFormInterface {

  /**
   * Get the source fields for which the plugin calculates the fallback value.
   *
   * @return string[]
   *   An array of source fields.
   */
  public function getSource(): array;

  /**
   * Get the target fields for which the plugin calculates the fallback value.
   *
   * @return string[]
   *   An array of target fields.
   */
  public function getTarget(): array;

  /**
   * Get the weight of the plugin.
   *
   * @return int
   *   The weight of the plugin.
   */
  public function getWeight(): int;

  /**
   * Converts the value of the given field to a new value.
   *
   * @param \Drupal\Core\Field\FieldItemListInterface $field
   *   The source field.
   *
   * @return mixed
   *   The converted value.
   */
  public function convert(FieldItemListInterface $field);

}
